CliTestSummary class
Summary of multiple test results
Constructors
-
CliTestSummary({required Map<
String, CliTestResult> results, required Map<String, String> errors}) -
const
Properties
- allPassed → bool
-
Whether all tests passed
no setter
- errorCount → int
-
Number of tests with errors
no setter
-
errors
→ Map<
String, String> -
final
- failureCount → int
-
Number of failed tests
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
results
→ Map<
String, CliTestResult> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successCount → int
-
Number of successful tests
no setter
- totalCount → int
-
Total number of tests
no setter
Methods
-
generateReport(
) → String - Generate a formatted report
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited